# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .country_code import CountryCode

__all__ = ["MiscListSupportedCountriesResponse"]

MiscListSupportedCountriesResponse: TypeAlias = List[CountryCode]
